@@ -6,7 +6,7 @@ Test::Strict - Check syntax, presence of use strict; and test coverage
 
 =head1 VERSION
 
-Version 0.37
+Version 0.38
 
 =head1 SYNOPSIS
 
@@ -71,7 +71,7 @@ use File::Find;
 use Config;
 
 our $COVER;
-our $VERSION = '0.37';
+our $VERSION = '0.38';
 our $PERL    = $^X || 'perl';
 our $COVERAGE_THRESHOLD = 50; # 50%
 our $UNTAINT_PATTERN    = qr|^(.*)$|;
@@ -258,6 +258,8 @@ our @MODULES_ENABLING_STRICT = qw(
     Coat
     common::sense
     Dancer
+    HTML::FormHandler::Moose
+    HTML::FormHandler::Moose::Role
     Mo
     Modern::Perl
     Mojo::Base
@@ -300,6 +302,8 @@ our @MODULES_ENABLING_WARNINGS = qw(
     Coat
     common::sense
     Dancer
+    HTML::FormHandler::Moose
+    HTML::FormHandler::Moose::Role
     Mo
     Modern::Perl
     Mojo::Base
